@@ -1,7 +1,7 @@
 from . import layers
 from .batch_norm_2d import set_default_batch_norm_2d, load_default_batch_norm_2d, reset_default_batch_norm_2d
 from .face import ArcFace
-from .losses import CrossEntropyLoss, LabelSmoothingLoss, L2Loss
+from .losses import CrossEntropyLoss, LabelSmoothingLoss, L2Loss, NormalizedL2Loss
 from .mobilenet_v2 import MobileNetV2
 from .mobilenet_v3 import MobileNetV3
 from .resnet import ResNet
